#
# spec file for package python-amqp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-amqp
Version:        2.1.4
Release:        47.2
Summary:        Low-level AMQP client for Python (fork of amqplib)
License:        LGPL-2.1+
Group:          Development/Languages/Python
Url:            http://github.com/celery/py-amqp
Source:         https://pypi.io/packages/source/a/amqp/amqp-%{version}.tar.gz
Source99:       %{name}.changes
BuildRequires:  %{python_module case}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module vine}
BuildRequires:  python-rpm-macros
Requires:       python-vine >= 1.1.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
This is a fork of amqplib_ which was originally written by Barry Pederson.
It is maintained by the Celery_ project, and used by kombu as a pure python
alternative when librabbitmq is not available.
This library should be API compatible with librabbitmq.

%prep
%setup -q -n amqp-%{version}

%build
%python_build

%install
%python_install

%check
%python_exec %{_bindir}/py.test

%files %python_files
%defattr(-,root,root,-)
%doc LICENSE
%{python_sitelib}/*

%changelog
* Wed Mar 15 2017 tbechtold@suse.com
- update to 2.1.4:
  - Removes byte string comparison warnings when running under ``python -b``.
  - Linux version parsing broke when the version included a '+' character
    (Issue #119).
  - Now sets default TCP settings for platforms that support them (e.g. Linux).
  - Fixes compatibility with Python 2.7.5 and below (Issue #107).
  - Linux: Now sets the :data:`~socket.TCP_USER_TIMEOUT` flag if available
    for better failed connection detection.
  - Python compatibility: Fixed compatibility when using the python ``-b`` flag.
  - Frame writer: Account for overhead when calculating frame size.
  - Frame writer: Account for overhead when calculating frame size.
  - Datetimes in method frame arguments are now handled properly.
  - Fixed compatibility with Python <= 2.7.6
  - Frame_writer is no longer a generator, which should solve
    a rare "generator already executing" error (Issue #103).
  - SSLTransport: Fixed crash "no attribute sslopts" when ``ssl=True``
    (Issue #100).
  - Fixed incompatible argument spec for ``Connection.Close`` (Issue #45).
    This caused the RabbitMQ server to raise an exception (INTERNAL ERROR).
  - Transport: No longer implements `__del__` to make sure gc can collect
    connections.
  - Python 3: Installation requirements ended up being a generator
    and crashed setup.py.
  - Python <= 2.7.7: struct.pack arguments cannot be unicode
  - Python 3.4: Fixed use of `bytes %% int`.
  - Connection/Transport: Fixed handling of default port.
  - Adds backward compatibility layer for the 1.4 API.
  - Fixes kombu 3.0/celery 3.1 compatibility (Issue #88).
  - Fixed compatibility with Python 2.7.3 (Issue #85)
  - Fixed bug where calling drain_events() with a timeout of 0 would actually
    block until a frame is received.
  - Documentation moved to http://amqp.readthedocs.io (Issue #89).
  - No longer supports Python 2.6
  - You must now call Connection.connect() to establish the connection.
  - Library rewritten to anticipate async changes.
  - Connection now exposes underlying socket options.
  - Additional logging for heartbeats.
  - SSL: Fixes issue with remote connection hanging
  - SSL: ``ssl`` dict argument now supports the ``check_hostname`` key
    (Issue #63).
- Drop tune-keepalive-intervals.diff . Similar solution applied upstream
- Drop amqp-drop-sphinxcontrib-issuetracker-dependency.patch. No longer
  needed
- Switch to singlespec approach
- Drop doc build
* Wed Jan 13 2016 antoine.belvire@laposte.net
- Update to 1.4.9:
  * Fix compatibility with Linux/OS X instances where the
    ``ctypes`` module does not exist
- Changes from 1.4.8:
  * ``abstract_channel.wait`` now accepts a float `timeout`
    parameter expressed in seconds
* Thu Dec 10 2015 seife+obs@b1-systems.com
- remove build date from documentation
* Mon Oct  5 2015 mcihar@suse.cz
- Add uniittest2 to BuildRequires for Python 2.6
* Sun Oct  4 2015 tbechtold@suse.com
- update to 1.4.7:
  * Fixed libSystem error on OS X 10.11 (El Capitan)
  * ``channel.basic_publish`` now raises :exc:`amqp.exceptions.NotConfirmed` on
    ``basic.nack``.
  * AMQP timestamps received are now converted from GMT instead of local time
    (Issue #67).
  * Wheel package installation now supported by both Python 2 and Python3.
- Add python-mock as BuildRequires. Needed for tests
* Thu Aug  6 2015 cdenicolo@suse.com
- license update: LGPL-2.1+
  LGPL includes "or later"
* Thu Jan 29 2015 dmueller@suse.com
- replace set_socket_TCP_KEEPALIVE_and_TCP_USER_TIMEOUT.patch
  with tune-keepalive-intervals.diff (bnc#902207)
* Mon Sep 15 2014 tbechtold@suse.com
- update to 1.4.6:
  * Now keeps buffer when socket times out.
  * Adds ``Connection.Transport`` attribute that can be used to specify
    a different transport implementation.
* Mon May  5 2014 dmueller@suse.com
- update to 1.4.5:
  - Can now deserialize more AMQP types.
  - SSL: Workaround for Python SSL bug.
  - ``Transport.__del_`` now handles errors occurring at late interpreter
  shutdown (Issue #36).
  - SSL transport accidentally disconnected after read timeout.
* Thu Mar  6 2014 speilicke@suse.com
- Add amqp-drop-sphinxcontrib-issuetracker-dependency.patch: Avoid
  unnesseary build-time dependencies.
* Thu Feb 20 2014 dmueller@suse.com
- update to 1.4.3:
  - Fixed bug where more data was requested from the socket
    than was actually needed.
  - Heartbeat negotiation would use heartbeat value from server even
    if heartbeat disabled (Issue #31).
* Tue Jan 21 2014 dmueller@suse.com
- update to 1.4.1:
  - Fixed error occurring when heartbeats disabled.
* Tue Jan 14 2014 dmueller@suse.com
- update to 1.4.0:
  - Heartbeat implementation improved (Issue #6).
  - NoneType is now supported in tables and arrays.
  - SSLTransport: Now handles ``ENOENT``.
* Sun Dec  1 2013 oliver.bengs@opensuse.org
- Update to 1.3.3:
  - SSLTransport: Now keeps read buffer if an exception is raised
  - Message.channel is now a channel object (not the channel id)
  - Now sets ``Message.channel`` on delivery
  - New option to wait for publish confirmations
  - ``queue_declare`` now returns named tuple of type
  - Contents of ``Channel.returned_messages`` is now named tuples.
  - Sockets now set to close on exec using the ``FD_CLOEXEC`` flag
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Apr 30 2013 speilicke@suse.com
- Run testsuite
* Mon Feb 11 2013 saschpe@suse.de
- Add Python3 support
- Build HTML documentation
- Install LICENSE, README.rst
* Mon Nov 12 2012 alexandre@exatati.com.br
- Update to 1.2.0:
  - New exception hierarchy:
  - amqp.AMQPError
  - amqp.ConnectionError
  - amqp.RecoverableConnectionError
  - amqp.ConsumerCancelled
  - amqp.ConnectionForced
  - amqp.ResourceError
  - IrrecoverableConnectionError
  - amqp.ChannelNotOpen
  - amqp.FrameError
  - amqp.FrameSyntaxError
  - amqp.InvalidCommand
  - amqp.InvalidPath
  - amqp.NotAllowed
  - amqp.UnexpectedFrame
  - amqp.AMQPNotImplementedError
  - amqp.InternalError
  - amqp.ChannelError
  - RecoverableChannelError
  - amqp.ContentTooLarge
  - amqp.NoConsumers
  - amqp.ResourceLocked
  - IrrecoverableChannelError
  - amqp.AccessRefused
  - amqp.NotFound
  - amqp.PreconditionFailed
* Thu Nov  8 2012 alexandre@exatati.com.br
- Update to 1.1.0:
  - No longer supports Pyhton 2.5
  - Fixed receiving of float table values.
  - Now Supports Python 3 and Python 2.6+ in the same source code.
  - Python 3 related fixes.
* Tue Nov  6 2012 alexandre@exatati.com.br
- Update to 1.0.2:
  - Now supports float values in headers/tables.
* Mon Nov  5 2012 alexandre@exatati.com.br
- Update to 1.0.1:
  - Connection errors does no longer include AttributeError.
  - Fixed problem with using the SSL transport in a non-blocking
    context.
    Fix contributed by Mher Movsisyan.
* Fri Sep 21 2012 alexandre@exatati.com.br
- Update to 0.9.4:
  - Adds support for exchange_bind and exchange_unbind.
    Contributed by Rumyana Neykova
  - Fixed bugs in funtests and demo scripts.
    Contributed by Rumyana Neykova
- Aditional changes from version 0.9.3:
  - Fixed bug that could cause the consumer to crash when reading
    large message payloads asynchronously.
  - Serialization error messages now include the invalid value.
* Fri Aug 24 2012 alexandre@exatati.com.br
- Initial package (0.9.2) for openSUSE.
